## START: Set by rpmautospec
## (rpmautospec version 0.3.0)
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           cfn-lint
Summary:        CloudFormation Linter
Version:        0.65.1
Release:        %autorelease

# SPDX
License:        MIT-0
URL:            https://github.com/aws-cloudformation/cfn-lint
Source0:        %{url}/archive/v%{version}/cfn-lint-%{version}.tar.gz
# Man page written for Fedora in groff_man(7) format based on --help output
Source1:        cfn-lint.1

BuildArch:      noarch

BuildRequires:  python3-devel

# Graph generation requires either pygraphviz or pydot; only the former is
# packaged, and it is preferred when both are available anyway.
BuildRequires:  python3dist(pygraphviz)
Requires:       python3dist(pygraphviz)

BuildRequires:  hardlink

BuildRequires:  python3dist(pytest)

# One function in cfnlint.maintenance calls “git grep”. It’s not entirely clear
# if this is really usable in a system-wide installation or not; it might be
# trying to operate on a git checkout of cfn-lint, which won’t be available. It
# doesn’t work for that reason when tested in
# TestUpdateDocumentation.test_update_docs, which is why there is no
# corresponding BuildRequires,
Recommends:     git-core

%py_provides python3-cfn-lint

%description
Validate AWS CloudFormation yaml/json templates against the AWS CloudFormation
Resource Specification and additional checks. Includes checking valid values
for resource properties and best practices.


%prep
%autosetup -n cfn-lint-%{version}


%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
# This saves, as of this writing, roughly 250kB in duplicate data files and
# __init__.py files. Note that we do not pass “-t” because we do not want to
# ignore or discard differences in mtime. Note also that rpmlint will complain
# about cross-directory hardlinks, but that these are not a problem because the
# contents of a directory owned by this package are guaranteed to be on a
# single filesystem.
hardlink '%{buildroot}%{python3_sitelib}/cfnlint'
%pyproject_save_files cfnlint
install -t '%{buildroot}%{_mandir}/man1' -D -p -m 0644 '%{SOURCE1}'


%check
# The checks on the graphviz/dot output appear to be excessively dependent on a
# particular version of pygraphviz:
#
#   >               assert len(file_contents) == len(expected_content) and
#                   sorted(file_contents) == sorted(expected_content)
#   E               AssertionError: assert (25 == 19)
#   E                +  where 25 = len(['digraph template {', ...])
#   E                +  and   19 = len(['digraph "template" {', ...])
k="${k-}${k+ and }not (TestTemplate and test_build_graph)"

# These tests want to make HTTP(S) requests to the Internet:
k="${k-}${k+ and }not (TestFormatters and test_sarif_formatter)"
k="${k-}${k+ and }not (TestUpdateResourceSpecs and test_update_resource_specs_python_2)"
k="${k-}${k+ and }not (TestUpdateResourceSpecs and test_update_resource_specs_python_3)"

# This test tries to use “git grep”, but there is no git repository.
k="${k-}${k+ and }not (TestUpdateDocumentation and test_update_docs)"

# Tests fail if we parallelize with pytest-xdist… so don’t do that!
%pytest -k "${k-}"


%files -f %{pyproject_files}
# pyproject-rpm-macros handles LICENSE and NOTICE (verify with “rpm -qL -p …”)

# We don’t provide a separate documentation package since all of the following
# documentation is still not very big. As of this writing, it totals ~250kB
# extracted and a couple dozen files, in the context of a base package that is
# >100MB extracted with around a thousand files.
%doc CHANGELOG.md
%doc CODE_OF_CONDUCT.md
%doc CONTRIBUTING.md
%doc README.md
# Markdown
%doc docs/
%doc examples/

%{_bindir}/cfn-lint
%{_mandir}/man1/cfn-lint.1*


%changelog
* Tue Sep 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.65.1-1
- Update to 0.65.1 (close RHBZ#2128106)

* Fri Sep 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.65.0-1
- Update to 0.65.0 (close RHBZ#2126573)

* Fri Sep 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.64.1-2
- Man page typo fixes

* Sun Sep 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.64.1-1
- Update to 0.64.1 (close RHBZ#2124643)

* Fri Sep 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.63.2-2
- Support for jsonschema 4.x is now via upstream PR#2336

* Wed Aug 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.63.2-1
- Update to 0.63.2 (close RHBZ#2122822)

* Tue Aug 30 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.63.1-1
- Update to 0.63.1 (close RHBZ#2122760)

* Thu Aug 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.63.0-1
- Update to 0.63.0 (close RHBZ#2119854)

* Thu Aug 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.5-1
- Update to 0.61.5 (close RHBZ#2117743)

* Sun Jul 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.4-2
- Confirm that License is SPDX MIT-0 (no License field change)

* Fri Jul 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.4-1
- Update to 0.61.4 (close RHBZ#2112420)

* Wed Jul 20 2022 Fedora Release Engineering <releng@fedoraproject.org> 0.61.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 18 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.3-1
- Update to 0.61.3 (close RHBZ#2108237)

* Tue Jul 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.2-1
- Update to 0.61.2 (close RHBZ#2105446)

* Wed Jun 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.1-3
- Correctly allow jsonschema 4.x (close RHBZ#2101852)

* Tue Jun 28 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.1-2
- Allow jsonschema 4.x (close RHBZ#2101852)

* Thu Jun 23 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.1-1
- Update to 0.61.1 (close RHBZ#2100086)

* Wed Jun 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.0-2
- Rebuilt for Python 3.11 (close RHBZ#2098682)

* Wed Jun 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.61.0-1
- Update to 0.61.0 (close RHBZ#2092104)

* Fri May 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.60.1-1
- Update to 0.60.1 (close RHBZ#2088569)

* Fri May 13 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.60.0-1
- Update to 0.60.0 (close RHBZ#2085999)

* Mon May 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.59.1-1
- Update to 0.59.1 (close RHBZ#2081089)

* Wed Apr 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.59.0-2
- Install man page directly rather than copying to source tree first

* Wed Apr 13 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.59.0-1
- Update to 0.59.0 (close RHBZ#2074634)

* Tue Mar 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.58.4-1
- Update to 0.58.4 (close RHBZ#2066498)

* Tue Mar 08 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.58.3-1
- Update to 0.58.3 (close RHBZ#2061852)

* Sat Feb 26 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.58.2-1
- Update to 0.58.1 (close RHBZ#2058798)

* Tue Feb 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.58.1-1
- Update to 0.58.1 (close RHBZ#2056627)

* Mon Jan 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.58.0-1
- Update to 0.58.0 (close RHBZ#2048684)

* Wed Jan 19 2022 Fedora Release Engineering <releng@fedoraproject.org> 0.57.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jan 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.57.0-1
- Update to 0.57.0 (close RHBZ#2042187)

* Wed Jan 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.56.4-1
- Update to 0.56.3 (close RHBZ#2039002)

* Thu Dec 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> 0.56.3-1
- Initial package (close RHBZ#2033083)
